@@ -7,7 +7,9 @@ pub mod dinic;
 pub mod edge;
 pub mod edmonds_karp;
 pub mod ford_fulkerson;
+pub mod geometry;
 pub mod graph;
+pub mod great_circle;
 pub mod kruskal;
 pub mod max_flow;
 pub mod projection;
@@ -15,3 +17,4 @@ pub mod rdx_sort;
 pub mod static_graph;
 pub mod tarjan;
 pub mod union_find;
+pub mod wgs84;
